require 'formula'

class Root < Formula
  homepage 'http://root.cern.ch'
  url 'ftp://root.cern.ch/root/root_v5.34.19.source.tar.gz'
  mirror 'http://ftp.riken.jp/pub/ROOT/root_v5.34.19.source.tar.gz'
  version '5.34.19'
  sha1 '77d3c7c6e2a7fd797382f5992d0181eb55566cb4'
  head 'https://github.com/root-mirror/root.git', :branch => 'v5-34-00-patches'

  option 'with-qt', "Build with Qt graphics backend and GSI's Qt integration"
  depends_on 'xrootd' => :recommended
  depends_on 'fftw' => :optional
  depends_on 'qt' => [:optional, 'with-qt3support']
  depends_on :x11 => :optional
  depends_on :python

  def install
    # brew audit doesn't like non-executables in bin
    # so we will move {thisroot,setxrd}.{c,}sh to libexec
    # (and change any references to them)
    inreplace Dir['config/roots.in', 'config/thisroot.*sh',
                  'etc/proof/utils/pq2/setup-pq2',
                  'man/man1/setup-pq2.1', 'README/INSTALL', 'README/README'],
      /bin.thisroot/, 'libexec/thisroot'

    # Determine architecture
    arch = MacOS.prefer_64_bit? ? 'macosx64' : 'macosx'

    # N.B. that it is absolutely essential to specify
    # the --etcdir flag to the configure script.  This is
    # due to a long-known issue with ROOT where it will
    # not display any graphical components if the directory
    # is not specified:
    # http://root.cern.ch/phpBB3/viewtopic.php?f=3&t=15072
    args = %W[
      #{arch}
      --all
      --enable-builtin-glew
      --enable-builtin-freetype
    ]

    if build.with? 'x11'
      args << "--disable-cocoa"
      args << "--enable-x11"
    end

    if build.with? 'qt'
      args << "--enable-qt"
      args << "--enable-qtgsi"
    end

    args += %W[
      --prefix=#{prefix}
      --etcdir=#{prefix}/etc/root
      --mandir=#{man}
    ]

    system "./configure", *args

    # ROOT configure script does not search for Qt framework
    if build.with? 'qt'
      inreplace "config/Makefile.config" do |s|
        s.gsub! /^QTLIBDIR .*/, "QTLIBDIR := -F #{Formula["qt"].opt_lib}"
        s.gsub! /^QTLIB .*/, "QTLIB := -framework QtCore -framework QtGui -framework Qt3Support"
      end
    end

    system "make"
    system "make install"

    # needed to run test suite
    prefix.install 'test'

    libexec.mkpath
    mv Dir["#{bin}/*.*sh"], libexec
  end

  def test
    system "make -C #{prefix}/test/ hsimple"
    system "#{prefix}/test/hsimple"
  end

  def caveats; <<-EOS.undent
    Because ROOT depends on several installation-dependent
    environment variables to function properly, you should
    add the following commands to your shell initialization
    script (.bashrc/.profile/etc.), or call them directly
    before using ROOT.

    For csh/tcsh users:
      source `brew --prefix root`/libexec/thisroot.csh
    For bash/zsh users:
      . $(brew --prefix root)/libexec/thisroot.sh
    EOS
  end
end
